@@ -338,7 +338,7 @@ fixupcodebookEntryMetric <- function(cbe){
   moments <- unname(cbe@stats$moments)
   m.1 <- moments[1]
   m.2 <- moments[2] - m.1^2
-  m.3 <- moments[3] - 3*moments[2]*m.1 - 2*m.1^3
+  m.3 <- moments[3] - 3*moments[2]*m.1 + 2*m.1^3
   m.4 <- moments[4] - 4*moments[3]*m.1 + 6*moments[2]*m.1^2 - 3*m.1^4
   miss <- cbe@stats$missings[1]
   NAs <- cbe@stats$missings[2]
